import tkinter as tk
from tkinter import filedialog, messagebox
import PyPDF2
import math
import os

def split_pdf(input_pdf_path, output_dir, num_parts):
    """
    Divise un fichier PDF en un nombre spécifié de sous-fichiers.
    
    :param input_pdf_path: Chemin du fichier PDF d'entrée.
    :param output_dir: Dossier de sortie.
    :param num_parts: Nombre de parties à créer.
    """
    try:
        # Sécurité : si num_parts est < 1, on arrête
        if num_parts < 1:
            raise ValueError("Le nombre de parties doit être au moins égal à 1.")
        
        with open(input_pdf_path, 'rb') as infile:
            reader = PyPDF2.PdfReader(infile)
            total_pages = len(reader.pages)
            
            # Calcul de la taille (approx.) de chaque segment, en arrondissant à l'entier supérieur
            chunk_size = math.ceil(total_pages / num_parts)
            
            # Nom de base pour les PDF de sortie (on retire l'extension .pdf au besoin)
            base_name = os.path.splitext(os.path.basename(input_pdf_path))[0]
            
            for i in range(num_parts):
                start_page = i * chunk_size
                end_page = min((i + 1) * chunk_size, total_pages)
                
                # Si start_page >= end_page, cela signifie qu'il n'y a plus de pages (cas extrême)
                if start_page >= end_page:
                    print(f"Partie {i+1}: aucune page à extraire (start={start_page}, end={end_page}).")
                    continue
                
                writer = PyPDF2.PdfWriter()
                for page_num in range(start_page, end_page):
                    writer.add_page(reader.pages[page_num])
                
                # Chemin de sortie pour cette partie
                output_pdf_path = os.path.join(
                    output_dir, f"{base_name}_part{i+1}.pdf"
                )
                
                with open(output_pdf_path, 'wb') as outfile:
                    writer.write(outfile)
                
                print(f"[OK] Fichier créé : {output_pdf_path}  (pages {start_page+1} à {end_page})")
            
            # Message de confirmation une fois toutes les parties créées
            messagebox.showinfo(
                "Succès",
                f"Le PDF a été divisé en {num_parts} parties dans le dossier :\n{output_dir}"
            )
    except Exception as e:
        messagebox.showerror("Erreur", f"Une erreur est survenue : {e}")

def browse_pdf():
    """Ouvre une boîte de dialogue pour sélectionner le fichier PDF."""
    file_path = filedialog.askopenfilename(
        title="Sélectionnez un fichier PDF",
        filetypes=[("Fichiers PDF", "*.pdf")]
    )
    if file_path:
        entry_pdf_path.delete(0, tk.END)
        entry_pdf_path.insert(0, file_path)

def browse_output_dir():
    """Ouvre une boîte de dialogue pour sélectionner le dossier de sortie."""
    directory = filedialog.askdirectory(title="Sélectionnez le dossier de sortie")
    if directory:
        entry_output_dir.delete(0, tk.END)
        entry_output_dir.insert(0, directory)

def split_pdf_action():
    """Récupère les chemins, le nombre de sous-fichiers et lance le découpage du PDF."""
    input_pdf_path = entry_pdf_path.get().strip()
    output_dir = entry_output_dir.get().strip()
    
    # Récupère la valeur saisie dans la Spinbox
    try:
        num_parts = int(spin_num_parts.get())
    except ValueError:
        messagebox.showwarning("Attention", "Veuillez saisir un nombre entier pour le nombre de sous-fichiers.")
        return
    
    # Vérifications de base
    if not input_pdf_path:
        messagebox.showwarning("Attention", "Veuillez sélectionner un fichier PDF.")
        return
    if not output_dir:
        messagebox.showwarning("Attention", "Veuillez sélectionner un dossier de sortie.")
        return
    if not os.path.isfile(input_pdf_path):
        messagebox.showerror("Erreur", "Le fichier PDF spécifié n'existe pas.")
        return
    if not os.path.isdir(output_dir):
        messagebox.showerror("Erreur", "Le dossier de sortie spécifié n'existe pas.")
        return
    
    # Lancement du découpage
    split_pdf(input_pdf_path, output_dir, num_parts)

# --- Création de la fenêtre principale ---
root = tk.Tk()
root.title("Découpe de PDF en N parties")

# --- Configuration de la fenêtre et des widgets ---

# Frame pour le chemin du PDF
frame_pdf = tk.Frame(root)
frame_pdf.pack(padx=10, pady=5, fill="x")

label_pdf = tk.Label(frame_pdf, text="Fichier PDF à découper :")
label_pdf.pack(side=tk.LEFT)

entry_pdf_path = tk.Entry(frame_pdf, width=50)
entry_pdf_path.pack(side=tk.LEFT, padx=5)

button_browse_pdf = tk.Button(frame_pdf, text="Parcourir...", command=browse_pdf)
button_browse_pdf.pack(side=tk.LEFT)

# Frame pour le dossier de sortie
frame_output = tk.Frame(root)
frame_output.pack(padx=10, pady=5, fill="x")

label_output = tk.Label(frame_output, text="Dossier de sortie :")
label_output.pack(side=tk.LEFT)

entry_output_dir = tk.Entry(frame_output, width=50)
entry_output_dir.pack(side=tk.LEFT, padx=5)

button_browse_output = tk.Button(frame_output, text="Parcourir...", command=browse_output_dir)
button_browse_output.pack(side=tk.LEFT)

# Frame pour la sélection du nombre de parties
frame_num_parts = tk.Frame(root)
frame_num_parts.pack(padx=10, pady=5, fill="x")

label_num_parts = tk.Label(frame_num_parts, text="Nombre de sous-fichiers :")
label_num_parts.pack(side=tk.LEFT)

# On peut utiliser Spinbox pour choisir un nombre facilement
spin_num_parts = tk.Spinbox(frame_num_parts, from_=1, to=999, width=5)
spin_num_parts.pack(side=tk.LEFT, padx=5)
spin_num_parts.delete(0, tk.END)
spin_num_parts.insert(0, "3")  # valeur par défaut

# Bouton pour lancer la découpe
button_split = tk.Button(root, text="Découper le PDF", command=split_pdf_action, bg="lightblue")
button_split.pack(pady=10)

root.mainloop()
